# File Renamer CLI

![Version](https://img.shields.io/badge/version-1.2-blue.svg)
![Lizenz](https://img.shields.io/badge/license-MIT-green.svg)
![Node.js](https://img.shields.io/badge/Node.js-%3E%3D14.0.0-brightgreen.svg)

Ein rekursives CLI-Tool zum Umbenennen von Dateien mit Suffix und automatischer TMDb-Titelerkennung. Ideal für die Organisation von Film- und Serien-Dateien.

## Features

- **Rekursives Umbenennen**: Verarbeitet Dateien in Ordnern und Unterordnern.
- **TMDb-Integration**: Erkennt Film- und Serientitel automatisch über die TMDb-API.
- **Konfigurierbare Suffixe**: Fügt benutzerdefinierte Suffixe zu Dateinamen hinzu.
- **Flexible Modi**:
  - Vorschau-Modus: Zeigt Änderungen ohne sie anzuwenden.
  - Vorschau mit Bestätigung: Änderungen werden nach Bestätigung durchgeführt.
  - Direkter Modus: Sofortiges Umbenennen ohne Vorschau.
- **Caching**: Speichert TMDb-Abfragen für schnellere Verarbeitung.
- **Konfigurationsmanagement**: Speichert Einstellungen in einer JSON-Datei.
- **Versionsprüfung**: Prüft automatisch auf Updates über Gitea.

## Voraussetzungen

- **Node.js**: Version >= 14.0.0
- **TMDb API-Token**: Erforderlich für die Titelabfrage. [Hier anmelden](https://www.themoviedb.org/documentation/api).
- Optional: `dotenv` für die Verwaltung von Umgebungsvariablen.

## Installation

1. **Repository klonen**:
   ```bash
   git clone https://git.viper.ipv64.net/M_Viper/file-renamer-cli.git
   cd file-renamer-cli

Hier ist eine passende GitHub README-Datei im Markdown-Format für dein Projekt "File Renamer CLI". Sie ist klar strukturiert, enthält alle wichtigen Informationen und folgt den Best Practices für eine professionelle README.

markdown

Kopieren
# File Renamer CLI

![Version](https://img.shields.io/badge/version-1.2-blue.svg)
![Lizenz](https://img.shields.io/badge/license-MIT-green.svg)
![Node.js](https://img.shields.io/badge/Node.js-%3E%3D14.0.0-brightgreen.svg)

Ein rekursives CLI-Tool zum Umbenennen von Dateien mit Suffix und automatischer TMDb-Titelerkennung. Ideal für die Organisation von Film- und Serien-Dateien.

## Features

- **Rekursives Umbenennen**: Verarbeitet Dateien in Ordnern und Unterordnern.
- **TMDb-Integration**: Erkennt Film- und Serientitel automatisch über die TMDb-API.
- **Konfigurierbare Suffixe**: Fügt benutzerdefinierte Suffixe zu Dateinamen hinzu.
- **Flexible Modi**:
  - Vorschau-Modus: Zeigt Änderungen ohne sie anzuwenden.
  - Vorschau mit Bestätigung: Änderungen werden nach Bestätigung durchgeführt.
  - Direkter Modus: Sofortiges Umbenennen ohne Vorschau.
- **Caching**: Speichert TMDb-Abfragen für schnellere Verarbeitung.
- **Konfigurationsmanagement**: Speichert Einstellungen in einer JSON-Datei.
- **Versionsprüfung**: Prüft automatisch auf Updates über Gitea.

## Voraussetzungen

- **Node.js**: Version >= 14.0.0
- **TMDb API-Token**: Erforderlich für die Titelabfrage. [Hier anmelden](https://www.themoviedb.org/documentation/api).
- Optional: `dotenv` für die Verwaltung von Umgebungsvariablen.

## Installation

1. **Repository klonen**:
   ```bash
   git clone https://git.viper.ipv64.net/M_Viper/file-renamer-cli.git
   cd file-renamer-cli
Abhängigkeiten installieren:
bash

Kopieren
npm install
TMDb API-Token konfigurieren: Erstelle eine .env-Datei im Projektverzeichnis und füge deinen TMDb API-Token hinzu:
env

Kopieren
TMDB_API_BEARER_TOKEN=dein_tmdb_token
Ersteinrichtung: Starte das Tool mit:
bash

Kopieren
node index.js --setup
Folge den Anweisungen, um den Ordner, Suffix und Umbenennungsmodus zu konfigurieren.
Verwendung
bash

Kopieren
node index.js
Ersteinrichtung: Wird automatisch gestartet, wenn keine gültige Konfiguration vorhanden ist oder --setup angegeben wird.
Ordnerauswahl: Wähle zwischen einem Standardordner (z. B. Desktop/Filme) oder einem benutzerdefinierten Pfad.
Suffix: Definiere einen Suffix, der an Dateinamen angehängt wird (z. B. @MyCollection).
Modi:
preview: Zeigt nur die geplanten Änderungen.
preview-confirm: Zeigt Änderungen und fragt nach Bestätigung.
direct: Benennt Dateien direkt um.
Beispielausgabe:

text

Kopieren
███████╗██╗██╗     ███████╗███╗   ██╗ █████╗ ███╗   ███╗███████╗      ██████╗██╗     ██╗
██╔════╝██║██║     ██╔════╝████╗  ██║██╔══██╗████╗ ████║██╔════╝     ██╔════╝██║     ██║
█████╗  ██║██║     █████╗  ██╔██╗ ██║███████║██╔████╔██║█████╗       ██║     ██║     ██║
██╔══╝  ██║██║     ██╔══╝  ██║╚██╗██║██╔══██║██║╚██╔╝██║██╔══╝       ██║     ██║     ██║
██║     ██║███████╗███████╗██║ ╚████║██║  ██║██║ ╚═╝ ██║███████╗     ╚██████╗███████╗██║
╚═╝     ╚═╝╚══════╝╚══════╝╚═╝  ╚═══╝╚═╝  ╚═╝╚═╝     ╚═╝╚══════╝     ╚═════╝╚══════╝╚═╝

╔══════════════════════════════════════╗
║             Version 1.2              ║
║               Script by              ║
║               @M_Viper               ║
║______________________________________║
║                                      ║
║ Gitea: https://git.viper.ipv64.net/M_Viper/file-renamer-cli ║
╚══════════════════════════════════════╝

Starte Umbenennung im Ordner: /home/user/Desktop/Filme
Suffix: @MyCollection
Umbenennungsmodus: preview

Vorschau der Änderungen (2):
Inception 2010.mp4 → Inception (2010) @MyCollection.mp4
Breaking Bad S01E01.mp4 → Breaking Bad S01E01 @MyCollection.mp4
Konfiguration
Die Konfigurationsdatei wird automatisch unter ~/Documents/config.json (oder relativ zur ausführbaren Datei in Produktion) gespeichert. Beispiel:

json

Kopieren
{
  "folderPath": "/home/user/Desktop/Filme",
  "suffix": "@MyCollection",
  "renameMode": "preview-confirm"
}
Abhängigkeiten
fs, path, os, readline, https (Node.js Standardbibliotheken)
dotenv (optional, für Umgebungsvariablen)
Lizenz
Dieses Projekt steht unter der MIT-Lizenz.

Autor
M_Viper
Webseite: m-viper.de
Gitea: git.viper.ipv64.net/M_Viper/file-renamer-cli
Beitrag
Beiträge sind willkommen! Bitte erstelle einen Fork, implementiere deine Änderungen und sende einen Pull Request.

Fork das Repository.
Erstelle einen Branch: git checkout -b feature/dein-feature.
Commit deine Änderungen: git commit -m 'Add: dein Feature'.
Push zum Branch: git push origin feature/dein-feature.
Erstelle einen Pull Request.
Bekannte Probleme
Bei hoher Anzahl an TMDb-Abfragen kann das Rate-Limit erreicht werden. Das Tool wartet automatisch und setzt die Abfrage fort.
Ungültige Ordnerpfade führen zur erneuten Aufforderung zur Konfiguration.
Roadmap
Unterstützung für weitere APIs (z. B. TVDB für Serien).
Batch-Verarbeitung für schnellere Umbenennung.
GUI-Option für einfachere Bedienung.
Kontakt
Für Fragen oder Vorschläge, kontaktiere mich über Gitea oder m-viper.de.

⭐ Star das Repository, wenn dir das Tool gefällt! ⭐

text

Kopieren

### Erklärung

- **Übersichtlichkeit**: Die README ist klar gegliedert mit Abschnitten wie Features, Installation, Verwendung, Konfiguration, etc.
- **ASCII-Art**: Das ASCII-Logo aus deinem Code ist integriert, um die Ästhetik beizubehalten.
- **Badges**: Version, Lizenz und Node.js-Version werden als Shields.io-Badges angezeigt.
- **Beispiele**: Enthält eine Beispielausgabe, die den Stil deines Banners widerspiegelt.
- **Links**: Verweist auf deine Gitea-Repository-URL und Webseite.
- **Best Practices**: Enthält Abschnitte für Beiträge, bekannte Probleme und eine Roadmap, um das Projekt professionell zu präsentieren.
- **Markdown-Syntax**: Nutzt Markdown für eine saubere Darstellung auf GitHub/Gitea.

Falls du Anpassungen wünschst (z. B. zusätzliche Abschnitte oder spezifische Formatierungen), lass es mich wissen!






1,8 s   